@@ -25,9 +25,11 @@ namespace Analitza
 {
 
 /**
- *	This class represents the mathml expression writer.
+ * \class MathMLExpressionWriter
+ * 
+ * \ingroup AnalitzaModule
  *
- *	@author Aleix Pol <aleixpol@kde.org>  
+ * \brief This class represents the mathml expression writer.
  */
 
 class MathMLExpressionWriter : public ExpressionWriter
@@ -41,6 +43,8 @@ class MathMLExpressionWriter : public ExpressionWriter
 		virtual QString accept(const Operator* var);
 		virtual QString accept(const Vector* var);
 		virtual QString accept(const List* l);
+		virtual QString accept(const Matrix* c);
+		virtual QString accept(const MatrixRow* c);
 		virtual QString accept(const Apply* a);
 		virtual QString accept(const CustomObject* c);
 		
